@@ -278,6 +278,7 @@ ellipse <- function(spatial_coord1, spatial_coord2, center, axes_lengths) {
 #' @importFrom ggplot2 geom_point
 #' @importFrom ggplot2 coord_cartesian
 #' @importFrom ggplot2 labs
+#' @importFrom ggplot2 scale_y_reverse
 #' @importFrom SpatialExperiment imgData
 #' @importFrom SpatialExperiment imgRaster
 #' @importFrom SpatialExperiment imgSource
@@ -352,31 +353,33 @@ gate_interactive <-
     }
 
     # Prepare spatial information
-    image <- 
-      SpatialExperiment::imgData(spe)[1, ]@listData$data[[1]] |>
-      SpatialExperiment::imgSource() |>
-      magick::image_read()
+    image_info <- 
+      SpatialExperiment::imgData(spe)[image_index, ]@listData$data[[1]] |>
+      SpatialExperiment::imgRaster() |>
+      magick::image_read() |>
+      magick::image_info()
     
     image_x_size <- 
-      magick::image_info(image)$width /
+      image_info$width /
       SpatialExperiment::imgData(spe)[image_index, ]@listData$scaleFactor
     
     image_y_size <- 
-      magick::image_info(image)$height /
+      image_info$height /
       SpatialExperiment::imgData(spe)[image_index, ]@listData$scaleFactor
     
     image_uri <- 
       SpatialExperiment::imgData(spe)[image_index, ]@listData$data[[1]] |>
       SpatialExperiment::imgRaster() |>
       plotly::raster2uri()
-    
+
     # Create plot 
     plot <-
       data |>
       ggplot2::ggplot(ggplot2::aes(x = x, y = y, key = .key)) +
+      ggplot2::scale_y_reverse() +
       ggplot2::coord_fixed(
-        xlim =  c(0, image_x_size), 
-        ylim = rev(c(0, image_y_size)), 
+        xlim = c(0, image_x_size), 
+        ylim = c(0, image_y_size), 
         expand = FALSE,
         ratio = 1
       )
@@ -448,10 +451,11 @@ gate_interactive <-
           source = image_uri,
           xref = "x",
           yref = "y",
-          x = 0,
-          y = 0,
+          x = 1,
+          y = 1,
           sizex = image_x_size,
           sizey = image_y_size,
+          yanchor = "top",
           sizing = "stretch",
           opacity = 1,
           layer = "below"
